package com.ruoyi.bst.booth.service.impl;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.changeRecord.domain.ChangeRecord;
import com.ruoyi.bst.changeRecord.domain.enums.ChangeRecordBstType;
import com.ruoyi.bst.changeRecord.mapper.ChangeRecordMapper;
import com.ruoyi.bst.device.domain.DeviceQuery;
import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.mapper.DeviceMapper;
import com.ruoyi.bst.device.service.DeviceIotService;
import com.ruoyi.bst.lightingNum.domain.LightingNum;
import com.ruoyi.bst.lightingNum.domain.LightingNumQuery;
import com.ruoyi.bst.lightingNum.domain.LightingNumVO;
import com.ruoyi.bst.lightingNum.mapper.LightingNumMapper;
import com.ruoyi.bst.lightingNum.service.LightingNumService;
import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.part.domain.PartVO;
import com.ruoyi.bst.part.service.PartService;
import com.ruoyi.bst.store.domain.StoreVO;
import com.ruoyi.bst.store.mapper.StoreMapper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.iot.constants.IotConstants;
import com.ruoyi.iot.domain.response.CommandResponse;
import com.ruoyi.iot.service.IotService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.booth.mapper.BoothMapper;
import com.ruoyi.bst.booth.domain.Booth;
import com.ruoyi.bst.booth.domain.BoothVO;
import com.ruoyi.bst.booth.domain.BoothQuery;
import com.ruoyi.bst.booth.service.BoothService;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * 卡座Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@Service
public class BoothServiceImpl implements BoothService
{
    @Autowired
    private BoothMapper boothMapper;
    @Autowired
    private PartService partService;
    @Autowired
    private DeviceMapper deviceMapper;
    @Autowired
    private TransactionTemplate transactionTemplate;
    @Autowired
    private DeviceIotService deviceIotService;
    @Autowired
    private StoreMapper storeMapper;
    @Autowired
    private LightingNumMapper lightingNumMapper;
    @Autowired
    private IotService iotService;
    @Autowired
    private ChangeRecordMapper changeRecordMapper;
    @Autowired
    private LightingNumService lightingNumService;

    /**
     * 查询卡座
     *
     * @param scope 卡座主键
     * @return 卡座
     */
    @Override
    public BoothVO selectBoothByBoothId(Long id, boolean scope)
    {
        if (id == null) {
            return null;
        }
        BoothQuery query = new BoothQuery();
        query.setBoothId(id);
        query.setScope(scope);
        return this.selectOne(query);
    }

    @Override
    public BoothVO selectOne(BoothQuery query) {
        PageHelper.startPage(1, 1);
        List<BoothVO> list = this.selectBoothList(query);
        return CollectionUtils.firstElement(list);
    }
    /**
     * 查询卡座列表
     *
     * @param booth 卡座
     * @return 卡座
     */
    @Override
    public List<BoothVO> selectBoothList(BoothQuery booth)
    {
        return boothMapper.selectBoothList(booth);
    }

    /**
     * 新增卡座
     *
     * @param booth 卡座
     * @return 结果
     */
    @Override
    public int insertBooth(Booth booth)
    {
        booth.setCreateTime(DateUtils.getNowDate());
        return boothMapper.insertBooth(booth);
    }

    /**
     * 修改卡座
     *
     * @param booth 卡座
     * @return 结果
     */
    @Override
    public int updateBooth(Booth booth)
    {
        return boothMapper.updateBooth(booth);
    }

    /**
     * 批量删除卡座
     *
     * @param boothIds 需要删除的卡座主键
     * @return 结果
     */
    @Override
    public int deleteBoothByBoothIds(List<Long> boothIds)
    {
        return boothMapper.deleteBoothByBoothIds(boothIds);
    }

    /**
     * 删除卡座信息
     *
     * @param boothId 卡座主键
     * @return 结果
     */
    @Override
    public int deleteBoothByBoothId(Long boothId)
    {
        return boothMapper.deleteBoothByBoothId(boothId);
    }



    @Override
    public int bindUser(Long userId, Long boothId) {
        BoothVO booth = boothMapper.selectBoothByBoothId(boothId);
        ServiceUtil.assertion(booth==null,"当前卡座不存在");
        if (booth.getExpiredTime() != null && booth.getExpiredTime().isAfter(LocalDateTime.now())) {
            // 卡座未过期，被其他用户绑定
            ServiceUtil.assertion(!booth.getUserId().equals(userId),"卡座已被绑定");
            // 卡座未过期，被当前用户绑定
            ServiceUtil.assertion(booth.getUserId().equals(userId),"请勿重复绑定该设备");
        }else {
            booth.setExpiredTime(LocalDateTime.now().plusMinutes(30));
            booth.setUserId(userId);
        }
        int i = boothMapper.updateBooth(booth);
        ServiceUtil.assertion(i==0,"操作失败");
        return i;
    }

    @Override
    public int lighting(BoothVO booth,Long userId) {

        // 判断当前用户是否在该店铺下有余额
        LightingNumVO vo = lightingNumMapper.selectLightingNumByUserId(userId,booth.getStoreId());
        ServiceUtil.assertion(vo == null,"请先购买余额");
        ServiceUtil.assertion(vo.getNumber()<=0,"余额不足，请充值");


        // 爆灯
        Integer result = transactionTemplate.execute(status -> {

            // 先扣减次数
            LightingNum data = new LightingNum();
            data.setNumber(1);
            OrderQuery query = new OrderQuery();
            query.setUserId(userId);
            query.setStoreId(booth.getStoreId());
            int i = lightingNumService.reduceLightingNumByQuery(data,query);
            ServiceUtil.assertion(i!=1,"操作失败");

            // 新建变化记录表
            ChangeRecord changeRecord = new ChangeRecord();
            changeRecord.setBstType(ChangeRecordBstType.LIGHTING.getCode());
            changeRecord.setUserId(userId);
            changeRecord.setStoreId(booth.getStoreId());
            changeRecord.setNumber(1);
            changeRecord.setBeforeNum(vo.getNumber());
            changeRecord.setAfterNum(vo.getNumber()-1);
            changeRecord.setCreateTime(DateUtils.getNowDate());
            changeRecord.setReason("用户爆灯");
            i = changeRecordMapper.insertChangeRecord(changeRecord);
            ServiceUtil.assertion(i!=1,"操作失败");

            this.lighting(booth);

            return i;
        });
        return result == null ? 0 : result;
    }

    public boolean lighting(BoothVO booth) {
        // 根据id查询出卡座对应的所有设备
        DeviceQuery deviceQuery = new DeviceQuery();
        deviceQuery.setBoothId(booth.getBoothId());
        deviceQuery.setDeleted(false);
        List<DeviceVO> deviceVOList = deviceMapper.selectDeviceList(deviceQuery);

        // 再进行设备爆灯
        if (deviceVOList != null && !deviceVOList.isEmpty()) {
            deviceVOList.forEach(deviceVO -> {
                boolean success = this.lighting(deviceVO);
                ServiceUtil.assertion(!success, "操作失败");
            });
        }

        return true;
    }

    @Override
    public boolean lighting(DeviceVO device) {
        ServiceUtil.assertion(device == null || device.getDeviceId() == null, "设备不存在");
        ServiceUtil.assertion(StringUtils.isAllBlank(device.getMac(), device.getMac2()), "设备MAC号为空");
        ServiceUtil.assertion(device.getDuration() == null,"当前设备暂未设置开启时长");
        CommandResponse res = iotService.setTime(device, device.getDuration(), "爆灯");
        ServiceUtil.assertion(res == null, "设备充值失败：未知错误");
        return true;
    }
}
