package com.ruoyi.bst.device.service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Objects;

import com.ruoyi.bst.bindRecord.domain.enums.BindRecordType;
import com.ruoyi.bst.device.domain.Device;
import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.domain.DeviceQuery;
import com.ruoyi.bst.device.domain.dto.DeviceWifiDTO;
import com.ruoyi.bst.device.domain.enums.DevicePowerStatus;

import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;

/**
 * 设备Service接口
 *
 * @author ruoyi
 * @date 2025-04-23
 */
public interface DeviceService
{
    /**
     * 查询设备
     *
     * @param deviceId 设备主键
     * @return 设备
     */
    public DeviceVO selectDeviceByDeviceId(Long deviceId);

    /**
     * 查询设备列表
     *
     * @param device 设备
     * @return 设备集合
     */
    public List<DeviceVO> selectDeviceList(DeviceQuery device);

    /**
     * 新增设备
     *
     * @param device 设备
     * @return 结果
     */
    public int insertDevice(Device device);

    /**
     * 修改设备
     *
     * @param device 设备
     * @return 结果
     */
    public int updateDevice(Device device);

    /**
     * 批量删除设备
     *
     * @param deviceIds 需要删除的设备主键集合
     * @return 结果
     */
    public int deleteDeviceByDeviceIds(Long[] deviceIds);

    /**
     * 删除设备信息
     *
     * @param deviceId 设备主键
     * @return 结果
     */
    public int deleteDeviceByDeviceId(Long deviceId);

    public int logicDel(List<Long> ids);

    /**
     * 绑定商户
     */
    String bindMch(Long deviceId, Long mchId);


    /**
     * 商户解绑设备
     *
     * @param deviceId 设备id
     */
    int unbind(Long deviceId);

    DeviceVO selectByDeviceNo(String value);

    /**
     * 根据mac修改在线状态
     */
    int updateOnlineStatusByMac(String mac, String status);


    /**
     * 查询一个
     */
    DeviceVO selectOne(DeviceQuery query);


    /**
     * 根据设备id绑定卡座
     * @param deviceId
     * @param boothId
     * @return
     */
    String bindBoothById(Long deviceId,Long boothId);

    /**
     * 根据设备SN绑定卡座
     * @param deviceNo
     * @param boothId
     * @return
     */
    String bindBoothBySN(String deviceNo,Long boothId);

    /**
     * 根据设备ID解除绑定
     * @param deviceId
     * @param userId
     * @param boothId
     * @return
     */
    public void unbindBooth(Long deviceId, Long userId, Long boothId);


    /**
     * 设置数据库爆灯时长
     * @param deviceId
     * @param duration
     * @return
     */
    public int setTimeDb(Long deviceId, Long duration);

}
