package com.ruoyi.web.app;

import com.aliyun.core.annotation.Path;
import com.ruoyi.bst.booth.domain.BoothVO;
import com.ruoyi.bst.booth.service.BoothService;
import com.ruoyi.bst.device.service.DeviceIotService;
import com.ruoyi.bst.device.service.DeviceService;
import com.ruoyi.bst.order.domain.dto.OrderCreateDTO;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LogBizType;
import com.ruoyi.common.utils.ServiceUtil;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;

@RestController
@RequestMapping("/app/booth")
@Slf4j
public class AppBoothController extends BaseController {

    @Autowired
    private BoothService boothService;


    @ApiOperation("爆灯")
    @PutMapping("/{boothId}/lighting")
    public AjaxResult lighting(@PathVariable @ApiParam("设备id") Long boothId) {
        if (boothId == null) {
            return error("卡座id不能为空");
        }
        BoothVO booth = boothService.selectBoothByBoothId(boothId);
        ServiceUtil.assertion(booth==null,"当前卡座信息不存在");
        ServiceUtil.assertion(booth.getStoreId()==null,"当前卡座未绑定店铺");
        ServiceUtil.assertion(booth.getUserId()==null,"请先绑定该卡座后再进行操作");
        ServiceUtil.assertion(booth.getExpiredTime().isBefore(LocalDateTime.now()), "请重新绑定卡座");
        ServiceUtil.assertion(!booth.getUserId().equals(getUserId()),"您操作当前卡座设备");
        return toAjax(boothService.lighting(booth,getUserId()));
    }

    @ApiOperation("用户绑定卡座")
    @PutMapping("/{boothId}/bindUser")
    @Log(title = "用户绑定卡座", businessType = BusinessType.OTHER, bizIdName = "arg0", bizType = LogBizType.BOOTH)
    public AjaxResult bindBooth(@PathVariable Long boothId) {
        if (boothId == null) {
            return error("卡座id不能为空");
        };
        return toAjax(boothService.bindUser(getUserId(),boothId));
    }

}
